@@ -2,12 +2,10 @@
 //!
 //! The example will hang if the feature is disabled, and will produce cohesive
 //! logs if it's enabled.
-extern crate fern;
-#[macro_use]
-extern crate log;
-
 use std::fmt;
 
+use log::{debug, info};
+
 fn main() {
     fern::Dispatch::new()
         .chain(std::io::stdout())
