@@ -21,6 +21,8 @@ use crate::{Filter, Formatter};
 use crate::{Syslog4Rfc3164Logger, Syslog4Rfc5424Logger, Syslog4TransformFn};
 #[cfg(all(not(windows), feature = "syslog-6"))]
 use crate::{Syslog6Rfc3164Logger, Syslog6Rfc5424Logger, Syslog6TransformFn};
+#[cfg(all(not(windows), feature = "syslog-7"))]
+use crate::{Syslog7Rfc3164Logger, Syslog7Rfc5424Logger, Syslog7TransformFn};
 
 pub enum LevelConfiguration {
     JustDefault,
@@ -72,6 +74,10 @@ pub enum Output {
     Syslog6Rfc3164(Syslog6Rfc3164),
     #[cfg(all(not(windows), feature = "syslog-6"))]
     Syslog6Rfc5424(Syslog6Rfc5424),
+    #[cfg(all(not(windows), feature = "syslog-7"))]
+    Syslog7Rfc3164(Syslog7Rfc3164),
+    #[cfg(all(not(windows), feature = "syslog-7"))]
+    Syslog7Rfc5424(Syslog7Rfc5424),
     Dispatch(Dispatch),
     SharedDispatch(Arc<Dispatch>),
     OtherBoxed(Box<dyn Log>),
@@ -150,6 +156,17 @@ pub struct Syslog6Rfc5424 {
     pub transform: Box<Syslog6TransformFn>,
 }
 
+#[cfg(all(not(windows), feature = "syslog-7"))]
+pub struct Syslog7Rfc3164 {
+    pub inner: Mutex<Syslog7Rfc3164Logger>,
+}
+
+#[cfg(all(not(windows), feature = "syslog-7"))]
+pub struct Syslog7Rfc5424 {
+    pub inner: Mutex<Syslog7Rfc5424Logger>,
+    pub transform: Box<Syslog7TransformFn>,
+}
+
 pub struct Panic;
 
 pub struct Null;
@@ -236,11 +253,7 @@ impl DateBasedConfig {
     }
 
     pub fn open_log_file(path: &Path) -> io::Result<fs::File> {
-        OpenOptions::new()
-            .write(true)
-            .create(true)
-            .append(true)
-            .open(path)
+        OpenOptions::new().create(true).append(true).open(path)
     }
 
     pub fn open_current_log_file(&self, suffix: &str) -> io::Result<fs::File> {
@@ -333,6 +346,10 @@ impl Log for Output {
             Output::Syslog6Rfc3164(ref s) => s.enabled(metadata),
             #[cfg(all(not(windows), feature = "syslog-6"))]
             Output::Syslog6Rfc5424(ref s) => s.enabled(metadata),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            Output::Syslog7Rfc3164(ref s) => s.enabled(metadata),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            Output::Syslog7Rfc5424(ref s) => s.enabled(metadata),
             Output::Panic(ref s) => s.enabled(metadata),
             Output::Writer(ref s) => s.enabled(metadata),
             #[cfg(feature = "date-based")]
@@ -364,6 +381,10 @@ impl Log for Output {
             Output::Syslog6Rfc3164(ref s) => s.log(record),
             #[cfg(all(not(windows), feature = "syslog-6"))]
             Output::Syslog6Rfc5424(ref s) => s.log(record),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            Output::Syslog7Rfc3164(ref s) => s.log(record),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            Output::Syslog7Rfc5424(ref s) => s.log(record),
             Output::Panic(ref s) => s.log(record),
             Output::Writer(ref s) => s.log(record),
             #[cfg(feature = "date-based")]
@@ -395,6 +416,10 @@ impl Log for Output {
             Output::Syslog6Rfc3164(ref s) => s.flush(),
             #[cfg(all(not(windows), feature = "syslog-6"))]
             Output::Syslog6Rfc5424(ref s) => s.flush(),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            Output::Syslog7Rfc3164(ref s) => s.flush(),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            Output::Syslog7Rfc5424(ref s) => s.flush(),
             Output::Panic(ref s) => s.flush(),
             Output::Writer(ref s) => s.flush(),
             #[cfg(feature = "date-based")]
@@ -634,7 +659,12 @@ impl Log for Sender {
 
 #[cfg(all(
     not(windows),
-    any(feature = "syslog-3", feature = "syslog-4", feature = "syslog-6")
+    any(
+        feature = "syslog-3",
+        feature = "syslog-4",
+        feature = "syslog-6",
+        feature = "syslog-7"
+    )
 ))]
 macro_rules! send_syslog {
     ($logger:expr, $level:expr, $message:expr) => {
@@ -737,6 +767,42 @@ impl Log for Syslog6Rfc5424 {
     fn flush(&self) {}
 }
 
+#[cfg(all(not(windows), feature = "syslog-7"))]
+impl Log for Syslog7Rfc3164 {
+    fn enabled(&self, _: &log::Metadata) -> bool {
+        true
+    }
+
+    fn log(&self, record: &log::Record) {
+        fallback_on_error(record, |record| {
+            let message = record.args().to_string();
+            let mut log = self.inner.lock().unwrap_or_else(|e| e.into_inner());
+            send_syslog!(log, record.level(), message);
+
+            Ok(())
+        });
+    }
+    fn flush(&self) {}
+}
+
+#[cfg(all(not(windows), feature = "syslog-7"))]
+impl Log for Syslog7Rfc5424 {
+    fn enabled(&self, _: &log::Metadata) -> bool {
+        true
+    }
+
+    fn log(&self, record: &log::Record) {
+        fallback_on_error(record, |record| {
+            let transformed = (self.transform)(record);
+            let mut log = self.inner.lock().unwrap_or_else(|e| e.into_inner());
+            send_syslog!(log, record.level(), transformed);
+
+            Ok(())
+        });
+    }
+    fn flush(&self) {}
+}
+
 impl Log for Panic {
     fn enabled(&self, _: &log::Metadata) -> bool {
         true
@@ -849,6 +915,8 @@ enum LogError {
     Syslog4(syslog4::Error),
     #[cfg(all(not(windows), feature = "syslog-6"))]
     Syslog6(syslog6::Error),
+    #[cfg(all(not(windows), feature = "syslog-7"))]
+    Syslog7(syslog7::Error),
 }
 
 impl fmt::Display for LogError {
@@ -860,6 +928,8 @@ impl fmt::Display for LogError {
             LogError::Syslog4(ref e) => write!(f, "{}", e),
             #[cfg(all(not(windows), feature = "syslog-6"))]
             LogError::Syslog6(ref e) => write!(f, "{}", e),
+            #[cfg(all(not(windows), feature = "syslog-7"))]
+            LogError::Syslog7(ref e) => write!(f, "{}", e),
         }
     }
 }
@@ -890,6 +960,13 @@ impl From<syslog6::Error> for LogError {
     }
 }
 
+#[cfg(all(not(windows), feature = "syslog-7"))]
+impl From<syslog7::Error> for LogError {
+    fn from(error: syslog7::Error) -> Self {
+        LogError::Syslog7(error)
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::LevelConfiguration;
